#!C:\b\abs_f95ipkx8z1\croot\gdal-split_1677573749254\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.6.0','rgb2pct.py'
__requires__ = 'GDAL==3.6.0'
__import__('pkg_resources').run_script('GDAL==3.6.0', 'rgb2pct.py')
